/**
 * BLOCK: gosign-button-block
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */
import classnames from "classnames";
import deprecated from './deprecated';
import MaterialUiIconPicker from 'react-material-ui-icon-picker';
import Style from 'style-it';
//  Import CSS.
import './style.scss';
import './editor.scss';

const { __ } = wp.i18n; // Import __() from wp.i18n
const { registerBlockType } = wp.blocks; // Import registerBlockType() from wp.blocks
const {PanelBody, Button, TextControl, ToggleControl, RangeControl,SelectControl, TabPanel } = wp.components; 
var AlignmentToolbar = wp.editor.AlignmentToolbar;
const { Fragment, Component  } = wp.element;
const {InspectorControls, PanelColorSettings, BlockControls, BlockAlignmentToolbar,MediaUpload } = wp.editor;

/**
 * Register: aa Gutenberg Block.
 *
 * Registers a new block provided a unique name and an object defining its
 * behavior. Once registered, the block is made editor as an option to any
 * editor interface where blocks are implemented.
 *
 * @link https://wordpress.org/gutenberg/handbook/block-api/
 * @param  {string}   name     Block name.
 * @param  {Object}   settings Block settings.
 * @return {?WPBlock}          The block, if it has been successfully
 *                             registered; otherwise `undefined`.
 */

 const matomoTrackingEnable = MATOMOJSOBJECT.Matomo === "1" ? true : false;

class GosignButton extends Component {

	static getInitialState( hover ) {
	    return {
	      hover: false,
	    };
  	}
  	
	constructor() {
    	super(...arguments);
    	this.state = this.constructor.getInitialState( this.props.attributes.hover );
    	this.toggleHover = this.toggleHover.bind(this);
  	}
  	toggleHover(){
		   this.setState({hover: !this.state.hover})
	}

	render() {

		const {
	      attributes,
	      setAttributes,
	    } = this.props;
	    const {
	      title,
	      description,
	      url,
	      buttoncolor,
	      buttontextcolor,
	      customSizeIcon,
	      customSizeFont,
		  iconColorCus,
		  iconName,
		  iconCode,
		  buttonSize,
		  bordercolor,
	      borderSize,
		  borderRadius,
		  alignment,
		  buttontextHcolor,
		  buttonHcolor,
		  iconPosition,
		  newtab,
		  transparent,
		  hover,
		  mediaID,
		  mediaURL,
		  matomoTracking,
		  matomoEventName,
		  matomoEventValue
	    } = attributes;
	    const onSelect = ( tabName ) => {};
	    
		/*function showPickedIcons(icon) {
			setAttributes({
				iconName: icon.name,
				iconCode: icon.code,
			});	
		}*/
		function emptymedia2(){
			setAttributes({iconName:"",iconCode:""});
		}
		function onIconSelect(media) {
			setAttributes({
				mediaURL: media.url,
				mediaID: media.id,
			});
			emptymedia2();
		}
		function showPickedIcons(icon) {
			setAttributes({
				iconName: icon.name,
				iconCode: icon.code,
			});
			emptyIcon();
		}

		function emptyIcon(){
			setAttributes({mediaURL:"",mediaID:""});
		}
		

	/*	function toggleHover(){
			console.log("here");
			console.log(hover);
		   this.setState({hover: !this.state.hover})
	  	}*/
	    const DisplayOptions = () => {
	        return (
	        	<Fragment>
	        		<TextControl
	        			label={ __( 'Button Label' ) }
	        			value={ title }
				       	onChange={value => setAttributes({ title: value })}
					    placeholder="Button label"
					    rel="noopener noreferrer"
				   	/>
				   	<TextControl
				   		label={ __( 'Button description' ) }
				   		value={ description }
				       	onChange={value => setAttributes({ description: value })}
					    placeholder="Button description"
					    rel="noopener noreferrer"
				   	/>
					<TextControl
						label={ __( 'Button URL' ) }
						value={ url }
				       	onChange={value => setAttributes({ url: value })}
					    placeholder="Button URL"
					    rel="noopener noreferrer"
				   	/>
				   	<SelectControl
			            label="Button Size"
			            value={buttonSize}
			            options={[
			              { label: "Small", value: "small" },
			              { label: "Medium", value: "medium" },
			              { label: "Large ", value: "large" }
			            ]}
			            onChange={buttonSize => {
			              setAttributes({ buttonSize });
			            }}
			         />
			       
						<AlignmentToolbar
							value={alignment}
							onChange={alignment => {
								setAttributes({ alignment: alignment });
							}}
							controls={[ "wide", "full"]}
					/>
					<PanelBody title={__("Title Font Size")}>
						<RangeControl
							label={__('Title Font Size in px')}
							value={customSizeFont}
							min='0'
							max='100'
							step='1'
							onChange={function( customSizeFont ) {
								setAttributes( { customSizeFont: customSizeFont } );
							}}
						/>
					</PanelBody>
					<ToggleControl
							label={__("Open in new tab")}
							checked={newtab}
							onChange={value => setAttributes({ newtab: value })}
					/>
					<ToggleControl
								label={__("Transparent Button")}
								checked={transparent}
								onChange={value => setAttributes({ transparent: value })}
					/>
					
					<PanelBody title={__("Button Color Settings")}>

						{transparent==false &&
						<PanelColorSettings
					   			
						  title={__("Background Color")}
						  initialOpen={false}
						  colorSettings={[
							{
							  value: buttoncolor,
							  onChange: buttoncolor => setAttributes({ buttoncolor: buttoncolor }),
							  label: __("Button Color")
						  	}
						  ]}
						/>
						}
						{transparent==true &&
							setAttributes({ buttoncolor: 'transparent' })
						}
						<PanelColorSettings
					   			
						  title={__("Text Color")}
						  initialOpen={false}
						  colorSettings={[
							{
							  value: buttontextcolor,
							  onChange: buttontextcolor => setAttributes({ buttontextcolor: buttontextcolor }),
							  label: __("Button Text Color")
							}
						  ]}
						/>
					</PanelBody>
					
					<PanelColorSettings
					  title={__("Button Hover Color")}
					  initialOpen={false}
					  colorSettings={[
						{
						  value: buttonHcolor,
						  onChange: buttonHcolor => setAttributes({ buttonHcolor: buttonHcolor }),
						  label: __("Button Hover Color")
					  	},
						{
						  value: buttontextHcolor,
						  onChange: buttontextHcolor => setAttributes({ buttontextHcolor: buttontextHcolor }),
						  label: __("Button Text Hover Color")
						}
					  ]}
					/>
					<PanelBody
						title="Border Settings"
						icon="category"
						initialOpen={false}>
						<Fragment>
							<PanelColorSettings
								title={ __( 'Border Color ' ) }
								initialOpen={false}
								colorSettings={ [
									{
										value: bordercolor,
										onChange: ( bordercolor ) => setAttributes( { bordercolor: bordercolor } ),
										label: __( 'Select Color' ),
									},
								] }
							>
							</PanelColorSettings>

							<RangeControl
								label={__('Enter Border Size its in px')}
								value={borderSize}
								min='0'
								max='10'
								step='1'
								onChange={function( borderSize ) {
									setAttributes( { borderSize: borderSize } );
								}}
							/>
							<RangeControl
								label={__('Enter Border Radius its in px')}
								value={borderRadius}
								min='0'
								max='10'
								step='1'
								onChange={function( borderRadius ) {
									setAttributes( { borderRadius: borderRadius } );
								}}
							/>
						</Fragment>
					</PanelBody>

					<PanelBody
						title="Set Icon"
						icon="category"
						initialOpen={false}
						className="iconSettingCus"
					>
							<Fragment>

								
								<Fragment>

									<div className="material-icons-block">
										<MaterialUiIconPicker onPick={showPickedIcons} label="Choose Icon" pickLabel="Select" />
										{iconName &&
											<Button className={iconName ? 'icon-button' : 'button button-large-remove'} onClick={  emptymedia2  }>
												<div class="remove-icon">Remove Icon</div>
											</Button>
										}
										<i className="material-icons">{iconName}</i>
										

									</div>
									
																<Fragment>
																	<MediaUpload
																		onSelect={onIconSelect}
																		type="image"
																		value={mediaID}
																		render={( { open } ) => (
																		<Fragment>
																		
																			<Button className={mediaID ? 'svg-button svg-button-icon' : 'svg-button button button-large'} onClick={open}>
																				{!mediaID ? __( 'Upload SVG' ) : <img src={mediaURL} />}
																			</Button>
																			<div className="material-icons-block">
																			{mediaID &&
																				<Button className={mediaID ? 'image-button' : 'button button-large-remove'} onClick={  emptyIcon  }>
																					{mediaID ? <div class="remove-icon"> Remove Icon</div> : ' '}
																				</Button>
																			}
																			{mediaID &&
																				<Button className={mediaID ? 'image-button' : 'button button-large-replace'} onClick={  open  }>
																					{mediaID ? <div class="remove-icon"> Replace Icon</div> : ' '}
																				</Button>
																			}
																			</div>
																		</Fragment>
																	)}
																	/>
																</Fragment>
															

									<PanelColorSettings
										title={ __( 'Choose Icon Color ' ) }
										initialOpen={false}
										colorSettings={ [
											{
												value: iconColorCus,
												onChange: iconColorCus => setAttributes({ iconColorCus: iconColorCus }),
												label: __( 'Select Color' ),
											},
										] }
									>
									</PanelColorSettings>
									<PanelBody title={__("Icon Size")}>
										<RangeControl
											label={__('Icon Size in px')}
											value={customSizeIcon}
											min='0'
											max='100'
											step='1'
											onChange={function( customSizeIcon ) {
												setAttributes( { customSizeIcon: customSizeIcon } );
											}}
										/>
									</PanelBody>
									<PanelBody title={__("Icon Position")}>
										<SelectControl
								            label="Icon Position"
								            value={iconPosition}
								            options={[
								              { label: "Right", value: "0" },
								              { label: "Left", value: "1" },
								            ]}
								            onChange={iconPosition => {
								              setAttributes({ iconPosition });
								            }}
								         />
									</PanelBody>
								</Fragment>

							</Fragment>
					</PanelBody>
					<br />
					{/* Matomo Tracking */}
					{matomoTrackingEnable &&
						<ToggleControl
							label={__("Enable Matomo Tracking")}
							checked={matomoTracking}
							onChange={value => setAttributes({ matomoTracking: value })}
						/>
					}
					{matomoTrackingEnable && matomoTracking &&
						<PanelBody
							title="Matomo Tracking"
							icon=""
							initialOpen={false}>
								<TextControl
									label={ __( 'Event Name' ) }
									value={ matomoEventName }
									onChange={value => setAttributes({ matomoEventName: value })}
									placeholder="Event Name"
									rel="noopener noreferrer"
								/>
								<SelectControl
									label="Event Type"
									value={matomoEventValue}
									options={[
										{ label: "OnClick", value: "click" },
										{ label: "OnMouseOver", value: "hover" },
									]}
									onChange={matomoEventValue => {
										setAttributes({ matomoEventValue });
									}}
								/>
						</PanelBody>
					}


	          	</Fragment>
	        );
	    };
		const inspectorControls = (
	      <InspectorControls>
	        <PanelBody title={__("Button Settings")} className="gosign-button-block"> 
	          {DisplayOptions()}
	        </PanelBody>
	      </InspectorControls>
	    );
	   
	   	var linkStyle;
	    if (!hover) {
	      linkStyle = {backgroundColor: buttonHcolor }
	    } 
	 
	    const DisplayButton = (

	    	<div className="button-block" style={{textAlign: alignment}}>
	    	
		       <Button type="submit" className={buttonSize}
	 style={{backgroundColor: buttoncolor, color:buttontextcolor,borderColor: bordercolor, borderRadius:borderRadius,borderWidth: borderSize}}>
		       <p style={{color:buttontextcolor}}>
		       {iconPosition == "1" && (

							<Fragment>
						
							{iconName &&
								<Fragment>
									<span className={iconName}>
										<i className="material-icons" style={{
											...(iconColorCus ? {color : iconColorCus }:{})
										}}>
											{iconName}
										</i>
									</span>
								</Fragment>
							}

						{mediaID &&
							<Fragment>
									<span className="mediaIcon">
										<img className="material-icons" src={mediaURL} width={customSizeIcon} />
									</span>
							</Fragment>
						}

							</Fragment>
				)}
				
				<span className={iconName ? "button-text" : ""}
				>
				
		       		{title}
	       		</span>

		       		{iconPosition == "0" && (
							<Fragment>
						
							{iconName &&
								<Fragment>
									<span className={iconName}>
										<i className="material-icons" style={{
											...(iconColorCus ? {color : iconColorCus }:{})
										}}>
											{iconName}
										</i>
									</span>
								</Fragment>
							}
							{mediaID &&
								<Fragment>
										<span className="mediaIcon">
											<img className="material-icons" src={mediaURL} width={customSizeIcon} />
										</span>
								</Fragment>
							}
							</Fragment>
						)}
						</p>
		       		

	       		<span className={iconName ? "button-text" : ""}>
		       		{description}
		       	</span>
		       </Button>
	       	</div>
	    );	

		return ( 
				<Fragment>
					{DisplayButton}
					{inspectorControls}
				</Fragment>
			)
		}
}


registerBlockType( 'gosign/button-block', {
	// Block name. Block names must be string that contains a namespace prefix. Example: my-plugin/my-custom-block.
	title: __( 'Gosign - Button Block' ), // Block title.
	icon: 'button', // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category: 'common', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords: [
		__( 'gosign-button-block — gosign Block' ),
		__( 'gosign' ),
		__( 'gosign block' ),
	],
	attributes: {
	    title: {
	    	type: 'string',
	    	default: 'Click Here',
	    },
	    description: {
			type: 'string',
		},
		url: {
			type: 'string',
		},
	    alignment: {
	        type: 'string',
	        selector: 'a',
	    },
	    buttoncolor: {
			type: "string",
			default: '#ffffff'
		},
		buttontextcolor: {
			type: "string",
			default: '#000000'
		},
		customSizeIcon: {
			default: 18+'px',
			type: 'int'
		},
		customSizeFont: {
			default: 18+'px',
			type: 'int'
		},
		iconColorCus: {
			type: 'string',
			default: '#000000'
		},
		iconName: {
			type: 'string',
			default: ''
		},
		iconCode: {
			type: 'string',
			default: ''
		},
		buttonSize: {
			type: 'string',
			default: 'small'
		},
		borderSize: {
			default: 1,
			type: 'number'
		},
		borderRadius: {
			default: 0,
			type: 'number'
		},
		bordercolor: {
			type: 'string',
			default: '#000000'
		},
		buttonHcolor: {
			type: 'string',
			default: '#000000'
		},
		buttontextHcolor: {
			type: 'string',
			default: '#ffffff'
		},
		hover: {
			type: 'boolean',
			default: false
		},
		iconPosition: {
			type: 'string',
			default: '0'
		},
		newtab: {
			type: "boolean",
	      	default: false,
		},
		transparent: {
			type: "boolean",
	      	default: false,
		},
		mediaID: {
			type: 'int'
		},
		mediaURL: {
			type: 'string',
			default: ''
		},
		matomoTracking: {
			type: "boolean",
	      	default: false,
		},
		matomoEventName: {
			type: 'string',
			default: ''
		},
		matomoEventValue: {
			type: 'string',
			default: 'click'
		}

	},

	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.
	 *
	 * The "edit" property must be a valid function.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
	 */

	edit: GosignButton,

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.
	 *
	 * The "save" property must be specified and must be a valid function.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
	 */
	save: function( props ) {
		var attributes = props.attributes;
		var title = props.attributes.title;
		var alignment = props.attributes.alignment;
		var description = props.attributes.description;
		var url = props.attributes.url;
		var buttoncolor = props.attributes.buttoncolor;
		var buttontextcolor = props.attributes.buttontextcolor;
		const { customSizeIcon,
				customSizeFont,
				iconColorCus,
				iconName,
				iconCode,
				buttonSize,
				bordercolor,
				borderSize,
				borderRadius,
				buttontextHcolor,
				buttonHcolor,
				iconPosition,
				newtab,
				transparent,
				mediaID,
				mediaURL,
				matomoTracking,
				matomoEventName,
				matomoEventValue
				
			 } = props.attributes;
		const {setAttributes} = props;
		let target="";

		let hoverEnterStyle = `this.style.cssText='color:${buttontextHcolor};background-color:${buttonHcolor};border-color:${bordercolor};border-radius:${borderRadius}px;border-width:${borderSize}px;'`;
		let hoverLeaveStyle = `this.style.cssText='color:${buttontextcolor};background-color:${buttoncolor};border-color:${bordercolor};border-radius:${borderRadius}px;border-width:${borderSize}px;'`;
		
		if(newtab == true){
			target= "_blank";
		}

		return (
		   	
			<div>
				<div style={{textAlign: alignment}}>
					
					<a className="button-block" href={url} target={target} rel="noopener noreferrer">
					
					<button style={{ backgroundColor: buttoncolor, color:buttontextcolor,borderColor: bordercolor,
		       	borderRadius:borderRadius,borderWidth: borderSize }} onmouseenter={hoverEnterStyle}
						onmouseleave={hoverLeaveStyle} className={buttonSize}
						{...(matomoTrackingEnable && matomoTracking ? {['data-MatomoEventName']: matomoEventName, ['data-MatomoEventValue']: matomoEventValue} : {})}
						{...(!matomoTrackingEnable && matomoTracking ? {['data-MatomoEventName']: matomoEventName, ['data-MatomoEventValue']: matomoEventValue} : {})}>
					
						{iconPosition == "1" && (
						<Fragment>
							
							{iconName &&
								<Fragment>
									<span className={iconName}>
										<i className="material-icons" style={{
											...(iconColorCus ? {color : iconColorCus }:{}),
											...(customSizeIcon ? {fontSize : customSizeIcon}:{})
										}}>
											{iconName}
										</i>
									</span>
								</Fragment>
							}
							{mediaID &&
								<Fragment>
										<span className="mediaIcon">
											<img className="material-icons" src={mediaURL} width={customSizeIcon} />
										</span>
								</Fragment>
							}
							</Fragment>
						)}
					<span className={iconName ? "button-text" : ""} style={{
						...(customSizeFont ? {fontSize : customSizeFont}:{})
					}}>
					{title}
					</span>
					{iconPosition == "0" && (
							<Fragment>
						
							{iconName &&
								<Fragment>
									<span className={iconName}>
										<i className="material-icons" style={{
											...(iconColorCus ? {color : iconColorCus }:{}),
											...(customSizeIcon ? {fontSize : customSizeIcon}:{})
										}}>
											{iconName}
										</i>
									</span>
								</Fragment>
							}
							{mediaID &&
								<Fragment>
										<span className="mediaIcon">
											<img className="material-icons" src={mediaURL} width={customSizeIcon} />
										</span>
								</Fragment>
							}
							</Fragment>
						)}
						
					<br></br>	
					<span className={iconName ? "button-text" : ""}>	
						{description}
					</span>
					</button>
					</a>
				</div>
			</div>
		);
	},
	deprecated, 
} );
